/*
   RX65N has two RAM areas
   0x00000000 - 0x0003FFFF = 256 kByte
   0x00800000 - 0x0085FFFF = 384 kByte

   The RAM is used for the following purposes:
   0x00000000 - 0x0003FFFF = 256 kByte Framebuffer => see ewmain.c
   0x00800000 - 0x0081FFFF = 128 kByte RAM provided to the linker, used for stack, variables and memroy pool
   0x00820000 - 0x0085FFFF = 256 kByte DoubleBuffer or extra memory pool => see ewmain.c

   This linker script is prepared for RX65N with 2MByte of flash in linear mode.
   0xFFE00000 - 0xFFFFFFFF = 2 Mbyte

*/

MEMORY
{
	RAM : ORIGIN = 0x00800000, LENGTH = 128k
	ROM : ORIGIN = 0xFFE00000, LENGTH = 2048k
	OFS : ORIGIN = 0xFE7F5D00, LENGTH = 256
}
SECTIONS
{
	.exvectors 0xFFFFFF80: AT(0xFFFFFF80)
	{
		KEEP(*(.exvectors))
	} > ROM
	.fvectors 0xFFFFFFFC: AT(0xFFFFFFFC)
	{
		KEEP(*(.fvectors))
	} > ROM
	.text 0xFFE00000: AT(0xFFE00000)
	{
		*(.text)
		*(.text.*)
		*(P)
		etext = .;
	} > ROM
	.rvectors :
	{
		_rvectors_start = .;
		KEEP(*(.rvectors))
		_rvectors_end = .;
	} > ROM
	.init :
	{
		KEEP(*(.init))
		__preinit_array_start = .;
		KEEP(*(.preinit_array))
		__preinit_array_end = .;
		__init_array_start = (. + 3) & ~ 3;
		KEEP(*(.init_array))
		KEEP(*(SORT(.init_array.*)))
		__init_array_end = .;
		__fini_array_start = .;
		KEEP(*(.fini_array))
		KEEP(*(SORT(.fini_array.*)))
		__fini_array_end = .;
	} > ROM
	.fini :
	{
		KEEP(*(.fini))
	} > ROM
	.got :
	{
		*(.got)
		*(.got.plt)
	} > ROM
	.rodata :
	{
		*(.rodata)
		*(.rodata.*)
		*(C_1)
		*(C_2)
		*(C)
		_erodata = .;
	} > ROM
	.eh_frame_hdr :
	{
		*(.eh_frame_hdr)
	} > ROM
	.eh_frame :
	{
		*(.eh_frame)
	} > ROM
	.jcr :
	{
		*(.jcr)
	} > ROM
	.tors :
	{
		__CTOR_LIST__ = .;
		. = ALIGN(2);
		___ctors = .;
		*(.ctors)
		___ctors_end = .;
		__CTOR_END__ = .;
		__DTOR_LIST__ = .;
		___dtors = .;
		*(.dtors)
		___dtors_end = .;
		__DTOR_END__ = .;
		. = ALIGN(2);
		_mdata = .;
	} > ROM
	.ustack 0x00802100: AT(0x00802100)
	{
		_ustack = .;
	} > RAM
	.istack 0x00800300: AT(0x00800300)
	{
		_istack = .;
	} > RAM
	.data 0x00802104: AT(_mdata)
	{
		_data = .;
		*(.data)
		*(.data.*)
		*(D)
		*(D_1)
		*(D_2)
		_edata = .;
	} > RAM
	.gcc_exc :
	{
		*(.gcc_exc)
	} > RAM
	.bss :
	{
		_bss = .;
		*(.bss)
		*(.bss.**)
		*(COMMON)
		*(B)
		*(B_1)
		*(B_2)
		_ebss = .;
		_end = .;
	} > RAM
}
