/*******************************************************************************
*
* E M B E D D E D   W I Z A R D   P R O J E C T
*
*                                                Copyright (c) TARA Systems GmbH
*                                    written by Paul Banach and Manfred Schweyer
*
********************************************************************************
*
* This software is delivered "as is" and shows the usage of other software
* components. It is provided as an example software which is intended to be
* modified and extended according to particular requirements.
*
* TARA Systems hereby disclaims all warranties and conditions with regard to the
* software, including all implied warranties and conditions of merchantability
* and non-infringement of any third party IPR or other rights which may result
* from the use or the inability to use the software.
*
********************************************************************************
*
* DESCRIPTION:
*   This file is part of the interface (glue layer) between an Embedded Wizard
*   generated UI application and the board support package (BSP) of a dedicated
*   target.
*   This template provides access to some LEDs and buttons of the board.
*
*******************************************************************************/

#include <stdlib.h>
#include <stdint.h>
#include <string.h>
#include "iodefine.h"

#include "ew_bsp_inout.h"

static TButtonCallback        ButtonCallback = NULL;


/*******************************************************************************
* FUNCTION:
*   EwBspInOutInitButton
*
* DESCRIPTION:
*   Configures one hardware button of the board used for demo applications.
*
* ARGUMENTS:
*   aButtonCallback - The button callback.
*
* RETURN VALUE:
*   None
*
*******************************************************************************/
void EwBspInOutInitButton( TButtonCallback aButtonCallback )
{
  /* enable writing to MPC pin function control registers */
  MPC.PWPR.BIT.B0WI = 0U;
  MPC.PWPR.BIT.PFSWE = 1U;

  /* set P05 to IRQ13 */
  MPC.P05PFS.BYTE = 0x40U;

  /* disable writing to MPC pin function control registers */
  MPC.PWPR.BIT.PFSWE = 0U;
  MPC.PWPR.BIT.B0WI = 1U;

  /* disable IRQ13 interrupt */
  IEN(ICU, IRQ13) = 0U;

  /* set up push button gpio input */
  PORT0.PMR.BIT.B5 = 0U;	/* mode to gpio */
  PORT0.PDR.BIT.B5 = 0U;	/* input */
  PORT0.PCR.BIT.B5 = 0U;  /* pull-up disable */

  /* disable IRQ13 digital filter */
  ICU.IRQFLTE1.BIT.FLTEN13 = 0U;

  /* trigger interrupt on both edges */
  ICU.IRQCR[13].BIT.IRQMD = 3U;

  /* clear any outstanding IRQ13 interrupt */
  IR(ICU, IRQ13) = 0U;

  /* set IRQ13 priority level */
  IPR(ICU, IRQ13) = 2U;

  /* enable IRQ13 interrupt */
  IEN(ICU, IRQ13) = 1U;

  ButtonCallback = aButtonCallback;
}


/*******************************************************************************
* FUNCTION:
*   EwBspInOutInitLed
*
* DESCRIPTION:
*   Configures one LED of the board used for demo applications.
*
* ARGUMENTS:
*   None
*
* RETURN VALUE:
*   None
*
*******************************************************************************/
void EwBspInOutInitLed( void )
{
  /* configure the LED gpio output */
  PORT7.PMR.BIT.B0 = 0U;
  PORT7.ODR0.BIT.B0 = 0U;
  PORT7.PDR.BIT.B0 = 1U;
  PORT7.PODR.BIT.B0 = 1U;
}


/*******************************************************************************
* FUNCTION:
*   EwBspInOutLedOn
*
* DESCRIPTION:
*   Switch LED on (used for demo applications).
*
* ARGUMENTS:
*   None
*
* RETURN VALUE:
*   None
*
*******************************************************************************/
void EwBspInOutLedOn( void )
{
  /* turn on the LED output */
  PORT7.PODR.BIT.B0 = 0U;
}


/*******************************************************************************
* FUNCTION:
*   EwBspInOutLedOff
*
* DESCRIPTION:
*   Switch LED off (used for demo applications).
*
* ARGUMENTS:
*   None
*
* RETURN VALUE:
*   None
*
*******************************************************************************/
void EwBspInOutLedOff( void )
{
  /* turn off the LED output */
  PORT7.PODR.BIT.B0 = 1U;
}


/*******************************************************************************
* FUNCTION:
*   EwBspInOutEventHandler
*
* DESCRIPTION:
*   The function EwBspInOutEventHandler is called from GPIO driver in case of
*   an input event.
*
* ARGUMENTS:
*   aEventId - An optional target specific event ID.
*
* RETURN VALUE:
*   None.
*
*******************************************************************************/
void EwBspInOutEventHandler( int aEventId )
{
  if ( ButtonCallback )
    ButtonCallback(( PORT0.PIDR.BIT.B5 == 0U ));
}


/* mli, msy */
