/*******************************************************************************
*
* E M B E D D E D   W I Z A R D   P R O J E C T
*
*                                                Copyright (c) TARA Systems GmbH
*                                    written by Paul Banach and Manfred Schweyer
*
********************************************************************************
*
* This software is delivered "as is" and shows the usage of other software
* components. It is provided as an example software which is intended to be
* modified and extended according to particular requirements.
*
* TARA Systems hereby disclaims all warranties and conditions with regard to the
* software, including all implied warranties and conditions of merchantability
* and non-infringement of any third party IPR or other rights which may result
* from the use or the inability to use the software.
*
********************************************************************************
*
* DESCRIPTION:
*   This file is part of the interface (glue layer) between an Embedded Wizard
*   generated UI application and the board support package (BSP) of a dedicated
*   target.
*   This template is responsible to configurate the entire system (CPU clock,
*   memory, qspi, etc).
*
*******************************************************************************/

#include <stdint.h>
#include <stdbool.h>
#include "iodefine.h"

#include "ew_bsp_system.h"
#include "ew_bsp_clock.h"

void SystemClock_Config(void);


/*******************************************************************************
* FUNCTION:
*   EwBspSystemInit
*
* DESCRIPTION:
*   The function EwBspSystemInit initializes the system components.
*   (CPU clock, memory, qspi, ...)
*
* ARGUMENTS:
*   None
*
* RETURN VALUE:
*   None
*
*******************************************************************************/
void EwBspSystemInit( void )
{
  SystemClock_Config();
}

void SystemClock_Config(void)
{
  /* enable all protect register bits */
  SYSTEM.PRCR.WORD = 0xA50B;

  /* main clock will be not oscillate in standby modes */
  SYSTEM.MOFCR.BIT.MOFXIN = 0x00;

  /* select resonator as main clock source */
  SYSTEM.MOFCR.BIT.MOSEL = 0x00;

  /* stop the HOCO, not using it */
  SYSTEM.HOCOCR.BIT.HCSTP = 0x01;

  /* turn off power to HOCO */
  SYSTEM.HOCOPCR.BYTE = 0x01;

  /* set driving ability for 12MHz input */
  SYSTEM.MOFCR.BIT.MODRV2 = 0x02;

  /* set wait time for starting main clock oscillator */
  SYSTEM.MOSCWTCR.BYTE = 0x53U;

  /* start main clock oscillator */
  SYSTEM.MOSCCR.BYTE = 0x00;

  /* dummy read to same register to ensure execution before next instruction */
  if ( 0x00 == SYSTEM.MOSCCR.BYTE )
    __asm("NOP");

  /* wait for main clock stabilization */
  while ( 0x00 == SYSTEM.OSCOVFSR.BIT.MOOVF )
    __asm("NOP");

  /* disable the sub-clock oscillator */
  SYSTEM.SOSCCR.BYTE = 0x01;

  /* dummy read to same register to ensure execution before next instruction */
  if ( 0x01 != SYSTEM.SOSCCR.BYTE )
    __asm("NOP");

  /* wait for stop of sub clock */
  while ( 0x00 != SYSTEM.OSCOVFSR.BIT.SOOVF )
    __asm("NOP");

  /* set PLL division to 1 */
  SYSTEM.PLLCR.BIT.PLIDIV = 0x00;

  /* clear PLL clock source if PLL clock source is main clock */
  SYSTEM.PLLCR.BIT.PLLSRCSEL = 0x00;

  /* set PLL multiplication to 20 => 12MHz * 20 = 240MHz */
  SYSTEM.PLLCR.BIT.STC = 0x27;

  /* start the PLL */
  SYSTEM.PLLCR2.BYTE = 0x00;

  /* wait for clock stabilization */
  while ( 0x00 == SYSTEM.OSCOVFSR.BIT.PLOVF )
    __asm("NOP");

  /* set rom wait state appropriate to main clock speed */
  SYSTEM.ROMWT.BYTE = 0x02;

  /* dummy read to same register to ensure execution before next instruction */
  if ( 0x02 == SYSTEM.ROMWT.BYTE )
    __asm("NOP");

  /* set system clock control register (SCKCR):
     ICK    = 120MHz
     FCK    = 60MHz
     BCK    = 120MHz
     PSTOP0 = 1
     PSTOP1 = 1
     PCLKA  = 120MHz
     PCLKB  = 60MHz
     PCLKC  = 60MHz
     PCLKD  = 60MHz
  */
  SYSTEM.SCKCR.LONG = 0x21C11222;

  /* dummy read to register */
  if ( 0x21C11222 == SYSTEM.SCKCR.LONG )
    __asm("NOP");

  /* no USB clock */
  SYSTEM.SCKCR2.WORD = 0x0010;

  /* dummy read to register */
  if ( 0x0010 == SYSTEM.SCKCR2.WORD )
    __asm("NOP");

  /* set system clock control register 3 (SCKCR3):
     CKSEL  = PLL
  */
  SYSTEM.SCKCR3.WORD = 0x0400;

  /* dummy read to register */
  if ( 0x0400 == SYSTEM.SCKCR3.WORD )
    __asm("NOP");

  /* turn off LOCO */
  SYSTEM.LOCOCR.BYTE = 0x01;

  /* disable all protect register bits */
  SYSTEM.PRCR.WORD = 0xA500;
}


/*******************************************************************************
* FUNCTION:
*   EwBspSystemDone
*
* DESCRIPTION:
*   The function EwBspSystemDone terminates the system components.
*
* ARGUMENTS:
*   None
*
* RETURN VALUE:
*   None
*
*******************************************************************************/
void EwBspSystemDone( void )
{
}


/* tzi, msy */
